@@ -61,6 +61,7 @@ class MainWindow:
 		self.tree.get_widget('edit_properties').set_sensitive(False)
 		self.tree.get_widget('move_up_button').set_sensitive(False)
 		self.tree.get_widget('move_down_button').set_sensitive(False)
+		self.tree.get_widget('new_separator_button').set_sensitive(False)
 		accelgroup = gtk.AccelGroup()
 		keyval, modifier = gtk.accelerator_parse('<Ctrl>Z')
 		accelgroup.connect_group(keyval, modifier, gtk.ACCEL_VISIBLE, self.on_mainwindow_undo)
@@ -74,6 +75,7 @@ class MainWindow:
 	def run(self):
 		self.loadMenus()
 		self.editor.applications.tree.add_monitor(self.menuChanged, None)
+		self.editor.settings.tree.add_monitor(self.menuChanged, None)
 		self.tree.get_widget('mainwindow').show_all()
 		gtk.main()
 
@@ -356,7 +358,15 @@ class MainWindow:
 			file_path = os.path.join(util.getUserItemPath(), item.get_desktop_file_id())
 			file_type = 'Item'
 		elif item.get_type() == gmenu.TYPE_DIRECTORY:
-			file_path = os.path.join(util.getUserDirectoryPath(), os.path.split(item.get_desktop_file_path())[1])
+			if item.get_desktop_file_path() == None:
+				file_path = util.getUniqueFileId('alacarte-made', '.directory')
+				parser = util.DesktopParser(file_path, 'Directory')
+				parser.set('Name', item.get_name())
+				parser.set('Comment', item.get_comment())
+				parser.set('Icon', item.get_icon())
+				parser.write(open(file_path))
+			else:
+				file_path = os.path.join(util.getUserDirectoryPath(), os.path.split(item.get_desktop_file_path())[1])
 			file_type = 'Menu'
 
 		if not os.path.isfile(file_path):
@@ -381,6 +391,7 @@ class MainWindow:
 		self.tree.get_widget('edit_properties').set_sensitive(False)
 		self.tree.get_widget('move_up_button').set_sensitive(False)
 		self.tree.get_widget('move_down_button').set_sensitive(False)
+		self.tree.get_widget('new_separator_button').set_sensitive(False)
 
 	def on_menu_tree_drag_data_get(self, treeview, context, selection, target_id, etime):
 		menus, iter = treeview.get_selection().get_selected()
@@ -396,6 +407,8 @@ class MainWindow:
 				context.finish(False, False, etime)
 				return False
 			if selection.target in ('ALACARTE_ITEM_ROW', 'ALACARTE_MENU_ROW'):
+				if self.drag_data == None:
+					return False
 				item = self.drag_data
 				new_parent = menus[path][2]
 				treeview.get_selection().select_path(path)
@@ -407,6 +420,7 @@ class MainWindow:
 				else:
 					context.finish(False, False, etime) 
 				context.finish(True, True, etime)
+		self.drag_data = None
 
 	def on_item_tree_show_toggled(self, cell, path):
 		item = self.item_store[path][3]
@@ -422,6 +436,7 @@ class MainWindow:
 		items, iter = treeview.get_selection().get_selected()
 		item = items[iter][3]
 		self.tree.get_widget('edit_delete').set_sensitive(True)
+		self.tree.get_widget('new_separator_button').set_sensitive(True)
 		if self.editor.canRevert(item):
 			self.tree.get_widget('edit_revert_to_original').set_sensitive(True)
 		else:
@@ -481,6 +496,8 @@ class MainWindow:
 			drop_info = treeview.get_dest_row_at_pos(x, y)
 			before = None
 			after = None
+			if self.drag_data == None:
+				return False
 			item = self.drag_data
 			if drop_info:
 				path, position = drop_info
@@ -500,6 +517,8 @@ class MainWindow:
 				self.editor.moveSeparator(item, item.get_parent(), before, after)
 			context.finish(True, True, etime)
 		elif selection.target == 'text/plain':
+			if selection.data == None:
+				return False
 			menus, iter = self.tree.get_widget('menu_tree').get_selection().get_selected()
 			parent = menus[iter][2]
 			drop_info = treeview.get_dest_row_at_pos(x, y)
@@ -530,6 +549,7 @@ class MainWindow:
 				self.editor.createItem(parent, parser.get('Icon'), parser.get('Name', self.editor.locale), parser.get('Comment', self.editor.locale), parser.get('Exec'), parser.get('Terminal'), before, after)
 			elif file_info.mime_type in ('application/x-shellscript', 'application/x-executable'):
 				self.editor.createItem(parent, None, os.path.split(file_path)[1].strip(), None, file_path.replace('file://', '').strip(), False, before, after)
+		self.drag_data = None
 
 	def on_item_tree_key_press_event(self, item_tree, event):
 		if event.keyval == gtk.keysyms.Delete:
@@ -595,6 +615,9 @@ class MainWindow:
 			pass
 		gobject.timeout_add(10, self.quit)
 
+	def on_style_set(self, *args):
+		self.loadUpdates()
+
 	def quit(self):
 		self.editor.quit()
 		gtk.main_quit()		
